@@ -1,5 +1,5 @@
 ;;;; psgml-dtd.el --- DTD parser for SGML-editing mode with parsing support
-;; $Id: psgml-dtd.el,v 1.3 2000/03/27 14:10:31 andreasj Exp $
+;; $Id: psgml-dtd.el,v 1.4 2000/10/06 08:38:12 youngs Exp $
 
 ;; Copyright (C) 1994 Lennart Staflin
 
@@ -168,7 +168,7 @@ Syntax: var dfa-expr &body forms"
     (setq l (sgml-state-opts s)
 	  nl (sgml-state-reqs s))
     (when yes
-      (sgml-debug "OPT redundant-1: sucess %s" (length yes))
+      (sgml-debug "OPT redundant-1: success %s" (length yes))
       (while (or l (setq l (prog1 nl (setq nl nil))))
 	(cond ((memq (sgml-move-dest (car l)) yes)
 	       (setf (sgml-move-dest (car l)) s)))
